searchData={"items":[{"type":"module","title":"Numa","doc":"Provides enum-like macros for defining a set of named constants with associated values.\n\nThis module allows you to easily define enums where each enum entry is represented as a macro\nthat returns a fixed value. It supports a mixed list of values and keyword pairs for flexible usage.","ref":"Numa.html"},{"type":"module","title":"Features - Numa","doc":"- Automatically creates macros named after enum keys (with a leading underscore).\n- Supports keys that are atoms, strings, or integers.\n- Supports values that can differ from the macro names.\n- Provides helper functions to retrieve all enum keys, values, or key-value pairs.\n- Validates inputs and raises clear errors on invalid types.","ref":"Numa.html#module-features"},{"type":"module","title":"Usage - Numa","doc":"","ref":"Numa.html#module-usage"},{"type":"module","title":"1. Simple list of values - Numa","doc":"When enum names and values are identical, provide a list of values (strings, atoms, or integers):\n\n    use Numa, [\"FULL\", \"1M\"]\n\nThis generates macros:\n\n    defmacro _FULL(), do: \"FULL\"\n    defmacro _1M(), do: \"1M\"   # Macro names are always prefixed with `_` to allow digits and avoid conflicts.","ref":"Numa.html#module-1-simple-list-of-values"},{"type":"module","title":"2. Keyword list with explicit keys and values - Numa","doc":"When macro names should differ from values, pass a keyword list:\n\n    use Numa, [M3: \"3m\", MINI: \"MINI\"]\n\nThis generates macros:\n\n    defmacro _M3(), do: \"3m\"\n    defmacro _MINI(), do: \"MINI\"","ref":"Numa.html#module-2-keyword-list-with-explicit-keys-and-values"},{"type":"module","title":"3. Using a function returning a list - Numa","doc":"You can also pass a zero-arity function that returns the enum list dynamically:\n\n    use Numa, fn -> [\"A\", \"B\", \"C\"] end","ref":"Numa.html#module-3-using-a-function-returning-a-list"},{"type":"module","title":"Generated helper functions - Numa","doc":"- `values/0` — returns a list of all enum values.\n- `keys/0` — returns a list of all macro names (as atoms).\n- `all/0` — returns a list of `{key, value}` tuples representing all enums.","ref":"Numa.html#module-generated-helper-functions"},{"type":"module","title":"Examples - Numa","doc":"iex> defmodule MyEnums do\n    ...>   use Numa, [\"FULL\", \"1M\", M3: \"3m\", mini: \"MINI\"]\n    ...> end\n    iex> MyEnums._FULL()\n    \"FULL\"\n    iex> MyEnums._1M()\n    \"1M\"\n    iex> MyEnums._M3()\n    \"3m\"\n    iex> MyEnums._mini()\n    \"MINI\"\n    iex> MyEnums.values()\n    [\"FULL\", \"1M\", \"3m\", \"MINI\"]\n    iex> MyEnums.keys()\n    [:_FULL, :_1M, :_M3, :_mini]\n    iex> MyEnums.all()\n    [\n      {:_FULL, \"FULL\"},\n      {:_1M, \"1M\"},\n      {:_M3, \"3m\"},\n      {:_mini, \"MINI\"}\n    ]","ref":"Numa.html#module-examples"},{"type":"module","title":"Error handling - Numa","doc":"Raises `ArgumentError` if the provided list contains unsupported types:\n\n    iex> defmodule A do use Numa, [%{}] end\n    ** (ArgumentError) Invalid Numa list value: %{}, expected type: atom, binary or integer","ref":"Numa.html#module-error-handling"},{"type":"module","title":"Notes - Numa","doc":"- Macro names are always prefixed with `_` to avoid conflicts and allow starting names with digits.\n- Keys in keyword lists must be atoms.\n- Values can be atoms, strings, or integers.","ref":"Numa.html#module-notes"},{"type":"extras","title":"Numa","doc":"# Numa\n\n[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE.md)\n[![Hex.pm](https://img.shields.io/hexpm/v/numa.svg)](https://hex.pm/packages/numa)\n[![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/numa/)\n\nNuma provides an easy way to define enum-like macros in Elixir.\n\nIt allows you to create named constants with associated values that can be used as compile-time macros.\nYou can pass a list of plain values or keyword pairs to automatically generate macros for your enums.\nThis is useful when you want efficient, readable constants without the overhead of runtime lookups.","ref":"readme.html"},{"type":"extras","title":"Features - Numa","doc":"- Define enums with mixed plain values (strings, atoms, integers) or explicit key-value pairs.\n- Macro names are automatically prefixed with `_` to ensure valid names, even if keys start with digits.\n- Provides helper functions to retrieve all enum keys, values, or key-value pairs.\n- Validates input and raises clear errors for invalid enum entries.","ref":"readme.html#features"},{"type":"extras","title":"Installation - Numa","doc":"Add `numa` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:numa, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen fetch dependencies:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Numa","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Defining simple enums - Numa","doc":"When names and values are the same:\n\n```elixir\ndefmodule MyEnums do\n  use Numa, [\"FULL\", \"1M\"]\nend\n\nMyEnums._FULL()  # => \"FULL\"\nMyEnums._1M()    # => \"1M\"\n```","ref":"readme.html#defining-simple-enums"},{"type":"extras","title":"Defining enums with explicit names and values - Numa","doc":"```elixir\ndefmodule MyEnums do\n  use Numa, [M3: \"3m\", MINI: \"MINI\"]\nend\n\nMyEnums._M3()    # => \"3m\"\nMyEnums._MINI()  # => \"MINI\"\n```","ref":"readme.html#defining-enums-with-explicit-names-and-values"},{"type":"extras","title":"Mixed enums and helper functions - Numa","doc":"```elixir\ndefmodule MyEnums do\n  use Numa, [\"FULL\", \"1M\", M3: \"3m\", mini: \"MINI\"]\nend\n\nMyEnums._FULL()    # => \"FULL\"\nMyEnums._1M()      # => \"1M\"\nMyEnums._M3()      # => \"3m\"\nMyEnums._mini()    # => \"MINI\"\n\nMyEnums.values()   # => [\"FULL\", \"1M\", \"3m\", \"MINI\"]\nMyEnums.keys()     # => [:_FULL, :_1M, :_M3, :_mini]\nMyEnums.all()      # => [{:_FULL, \"FULL\"}, {:_1M, \"1M\"}, {:_M3, \"3m\"}, {:_mini, \"MINI\"}]\n```","ref":"readme.html#mixed-enums-and-helper-functions"},{"type":"extras","title":"Dynamic enum list - Numa","doc":"You can also pass a function returning a list:\n\n```elixir\ndefmodule MyEnums do\n  use Numa, fn -> [\"A\", \"B\", \"C\"] end\nend\n\nMyEnums._A()   # => \"A\"\n```","ref":"readme.html#dynamic-enum-list"},{"type":"extras","title":"Error handling - Numa","doc":"Invalid input raises clear errors:\n\n```elixir\ndefmodule InvalidEnums do\n  use Numa, [%{}]  # Raises ArgumentError: Invalid Numa list value: %{}, expected type: atom, binary or integer\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Documentation - Numa","doc":"Documentation is generated with [ExDoc](https://github.com/elixir-lang/ex_doc) and published on [HexDocs](https://hexdocs.pm/numa).\n\n---\n\nCreated and maintained by [Centib](https://github.com/Centib).","ref":"readme.html#documentation"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Centib\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}